@@ -17,7 +17,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * (C) Copyright 2008 Red Hat, Inc.
+ * (C) Copyright 2008 - 2010 Red Hat, Inc.
  */
 
 #include <string.h>
@@ -88,21 +88,27 @@ finish_setup (CEPageVpn *self, gpointer unused, GError *error, gpointer user_dat
 }
 
 CEPage *
-ce_page_vpn_new (NMConnection *connection, GtkWindow *parent_window, GError **error)
+ce_page_vpn_new (NMConnection *connection,
+                 GtkWindow *parent_window,
+                 const char **out_secrets_setting_name,
+                 GError **error)
 {
 	CEPageVpn *self;
 	CEPageVpnPrivate *priv;
-	CEPage *parent;
 	const char *service_type;
 
-	self = CE_PAGE_VPN (g_object_new (CE_TYPE_PAGE_VPN,
-	                                  CE_PAGE_CONNECTION, connection,
-	                                  CE_PAGE_PARENT_WINDOW, parent_window,
-	                                  NULL));
-	parent = CE_PAGE (self);
-	priv = CE_PAGE_VPN_GET_PRIVATE (self);
+	self = CE_PAGE_VPN (ce_page_new (CE_TYPE_PAGE_VPN,
+	                                 connection,
+	                                 parent_window,
+	                                 NULL,
+	                                 NULL,
+	                                 _("VPN")));
+	if (!self) {
+		g_set_error_literal (error, 0, 0, _("Could not load VPN user interface."));
+		return NULL;
+	}
 
-	parent->title = g_strdup (_("VPN"));
+	priv = CE_PAGE_VPN_GET_PRIVATE (self);
 
 	priv->setting = (NMSettingVPN *) nm_connection_get_setting (connection, NM_TYPE_SETTING_VPN);
 	g_assert (priv->setting);
@@ -119,10 +125,8 @@ ce_page_vpn_new (NMConnection *connection, GtkWindow *parent_window, GError **er
 	}
 
 	g_signal_connect (self, "initialized", G_CALLBACK (finish_setup), NULL);
-	if (!ce_page_initialize (parent, NM_SETTING_VPN_SETTING_NAME, error)) {
-		g_object_unref (self);
-		return NULL;
-	}
+
+	*out_secrets_setting_name = NM_SETTING_VPN_SETTING_NAME;
 
 	return CE_PAGE (self);
 }
